#General
import zLOG
import Globals
from Globals import PersistentMapping
from Persistence import Persistent
from types import *
from AccessControl import ClassSecurityInfo

#CMF
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.CMFCorePermissions import ManageProperties
from Products.CMFCore.CMFCorePermissions import ModifyPortalContent
from Products.CMFCore.CMFCorePermissions import ManagePortal
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFDefault.utils import tuplize

factory_type_information = {
	'id': 'Currency Manager',
	'meta_type': 'MMM Shop Currency Manager',
	'description': 'Use currency manager to administrate your shops currencies',
	'product': 'MMMShop',
	'icon': 'file_icon.gif',
	'factory': 'addCurrencyManager',
	'filter_content_types': 0,
	'immediate_view': 'currencymanager_edit_form',
	'actions':
		({'name': 'View',
		  'action': 'currencymanager_view',
		  'permissions': ('ManagePortal',),
		  'category': 'object'},
		 {'name': 'Edit',
		  'action': 'currencymanager_edit_form',
		  'permissions': ('ManagePortal',),
		  'category': 'object'})
	}

class CurrencyObject(Persistent):
    currencyManager = None
    name = None
    code = None
    rate = None
    monetary_unit = None
    security = ClassSecurityInfo()

    def __init__(self, currencyManager, name, code, rate, monetary_unit):
	self.currencyManager = currencyManager
	self.name = name
	self.code = code
	self.rate = rate
	self.monetary_unit = monetary_unit

    security.declarePublic('getName')
    def getName(self):
	return self.name

    security.declarePublic('getCode')
    def getCode(self):
	return self.code

    security.declarePublic('getRate')
    def getRate(self):
	return self.rate

    security.declarePublic('getMonetaryUnit')
    def getMonetaryUnit(self):
	return self.monetary_unit

    security.declarePublic('setName')
    def setName(self, name=None):
        if name is not None:
	   self.name = name

    security.declarePublic('setCode')
    def setCode(self, code=None):
        if code is not None:
	   self.code = code

    security.declarePublic('setRate')
    def setRate(self, rate=None):
	if rate is not None:
	   self.rate = rate

    security.declarePublic('setMonetaryUnit')
    def setMonetaryUnit(self, monetary_unit=None):
	if monetary_unit is not None:
	   self.monetary_unit = monetary_unit
		    
class CurrencyManager(PortalContent, DefaultDublinCoreImpl):

    """
    A Currency Manager
    """

    meta_type = 'MMM Shop Currency Manager'
    portal_type='Object'
    effective_date = expiration_date = None
    _isDiscussable = 1
    security = ClassSecurityInfo()
    
    def __init__(self
    		, id
		, title = 'Currency Manager'
		, description = ''
		):
	DefaultDublinCoreImpl.__init__(self)
	self.id = id
	self.title = title
	self.description = description
	self.currencies = []
	zLOG.LOG("CurrencyManager", 0, "CurrencyManager created %s" % (id))

    security.declarePublic('listCurrencies')
    def listCurrencies(self):
	"""
	List all availiable currencies
	"""
	return tuple(self.currencies)

    security.declareProtected(View, 'getCurrency')
    def getCurrency(self, id):
	"""
	Get specific currency
	"""
	zLOG.LOG("CurrencyManager", 0, "Requesting currency %s returning: %s" % (id, self.currencies[id]))
	return self.currencies[id]

    security.declareProtected(ManageProperties, 'delCurrency')
    def delCurrency(self, id):
	"""
	Delete a currency from the manager
	"""
	zLOG.LOG("CurrencyManager", 0, "Delete a currency with id %s from currency manager" % (id))
	del self.currencies[id]
	self._p_changed = 1

    security.declareProtected(ManageProperties, 'addCurrency')
    def addCurrency(self, name, code, rate, monetary_unit):
	"""
	Add another Currency with it's data to the Currency Manager
	"""
	zLOG.LOG("Currency Manager", 0, "Add this currency (name: %s, code: %s, rate: %s, monetary unit: %s) to the Currency Manager" % (name, code, rate, monetary_unit))

	for item in self.currencies:
	    if item.code == code:
	       return

        self.currencies.append(CurrencyObject(currencyManager=self, name=name, code=code, rate=rate, monetary_unit=monetary_unit))
	self._p_changed = 1

    security.declareProtected(ManageProperties, 'clearCurrencies')
    def clearCurrencies(self):
	self.currencies = []
	self._p_changed = 1

    def SearchableText(self):
	"""
	Text for indexing
	"""
	return "%s %s" % (self.title, self.description)

    def cb_isMoveable(self):
	"""
	You cannot move this object
	"""
	return 0

    def cb_isCopyable(self):
	"""
	You cannot copy this object
	"""
	return 0

def addCurrencyManager(self, id, title='', REQUEST=None):
	ob=CurrencyManager(id, title)
	self._setObject(id, ob)

Globals.InitializeClass(CurrencyManager)

from Products.CMFCore.register import registerPortalContent
registerPortalContent(CurrencyManager,
		      constructors=(addCurrencyManager,),
		      action='currencymanager_edit_form',
		      icon='file_icon.gif')
