##############################################################################
#    Copyright (C) 2001  MMmanager.org
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##############################################################################
"""
"""

ADD_CONTENT_PERMISSION = 'Add portal content'

import Globals
import string
import zLOG
from Persistence import Persistent
from Globals import HTMLFile
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.CMFCorePermissions import ManageProperties
from AccessControl import getSecurityManager, ClassSecurityInfo
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
from Products.CMFCore.utils import getToolByName
from popen2 import popen2
from OFS.Traversable import Traversable
from Acquisition import aq_base
from Products.CMFCore.WorkflowCore import WorkflowMethod

factory_type_information = {
      'id': 'Shop Order',
      'meta_type': 'MMM Shop Order',
      'description': 'Use orders to get the products to your customers',
      'product': 'MMMShop',
      'icon': 'file_icon.gif',
      'factory': 'addShopOrder',
      'filter_content_types': 0,
      'immediate_view': 'shoporder_edit_form',
      'actions':
	      ({'name': 'View',
	        'action': 'shoporder_view',
		'permissions': ('View',),
		'category': 'object'},
	       {'name': 'Edit',
	        'action': 'shoporder_edit_form',
		'permissions': ('Modify portal content',),
		'category': 'object'})
       }

class OrderObject(Persistent):
    order = None
    quantity = None
    product = None
    security = ClassSecurityInfo()

    def __init__(self, order, product, quantity, variant=None, price=0.0):
        self.order = order
	self.quantity = int(quantity)
	self.product = product
	self.variant = variant
	self.price = price

    security.declarePublic('getOrder')
    def getOrder(self):
	return self.order

    security.declarePublic('getProduct')
    def getProduct(self):
	return self.product

    security.declarePublic('getQuantity')
    def getQuantity(self):
	return self.quantity

    security.declarePublic('getVariant')
    def getVariant(self):
	return self.variant

    security.declarePublic('getPrice')
    def getPrice(self):
	return self.price

class ShopOrder( PortalContent
          , DefaultDublinCoreImpl
          ):
    """
        A Link
    """

    meta_type='MMM Shop Order'
    portal_type='Object'
    effective_date = expiration_date = None
    _isDiscussable = 1
    name = ''
    address = ''
    zipcode = ''
    city = ''
    country = ''
    email = ''
    amount = 0
    phone = ''
    orderid = ''
    vat = 0.0
    send_fee = 0.0
    exchange_fee = 0.0
    euvat = ''
    organisation = ''

    security = ClassSecurityInfo()

    doOrderemail = HTMLFile('dtml/sendMail', globals())
    PGPmailString = HTMLFile('dtml/PGPmailString', globals())

    def __init__( self
                , id
                ):
        DefaultDublinCoreImpl.__init__(self)
        self.id=id
	self.products = []
	self.title = ''
	self.description = ''

    security.declarePublic('listProducts')
    def listProducts(self):
	"""
	List all products in this order
	"""

	return tuple(self.products)

    security.declarePublic('getTotalPrice')
    def getTotalPrice(self):
    	"""
    	Get the total price for this order exc. VAT
    	"""
    	all_price = self.send_fee
    	for item in self.products:
    	  all_price = all_price + float(item.quantity) * item.price
    	return all_price

    security.declarePublic('getTotalPriceVAT')
    def getTotalPriceVAT(self):
    	"""
    	Get the total price for this order exc. VAT
    	"""
    	all_price = self.getTotalPrice()
    	return all_price * ( 1 + self.vat)

    security.declareProtected(View, 'getProduct')
    def getProduct(self, id):
	zLOG.LOG("Order", 0, "Fetching product %s return: %s" % (id, self.products[id]))
	return self.products[id]

    security.declarePublic('delProduct')
    def delProduct(self, id):
	"""
	Delete a product from the order
	"""
	zLOG.LOG("Order", 0, "Delete product with id %s from this order" % (id))
	del self.products[id]
	self._p_changed = 1

    security.declareProtected(ManageProperties, 'addProductToOrder')
    def addProductToOrder(self, product, quantity, variant=None, price=0.0):
	"""
	Assigns a product and a quantity to the order
	"""
	zLOG.LOG("Order", 0, "Add %s (quantity: %s) to order %s" % (product, quantity, self.id))
	container = aq_base(self)
	for item in self.products:
	    if item.product == product and item.variant == variant:
	       item.quantity = int(item.quantity) + int(quantity)
	       return

        self.products.append(OrderObject(order=self, product=product, quantity=quantity, variant=variant, price=price))
        self._p_changed = 1

    def setPersonalDetails(self, REQUEST):
	self.name = REQUEST['cust_name']
	self.organisation = REQUEST['cust_organisation']
	self.address = REQUEST['cust_address']
	self.zipcode = REQUEST['cust_zipcode']
	self.city = REQUEST['cust_city']
	self.country = REQUEST['cust_country']
	self.phone = REQUEST['cust_phone']
	self.email = REQUEST['cust_email']
	self.orderid = REQUEST['orderid']
	self.euvat = REQUEST['cust_vat']

    def setOrderId(self, orderid=None):
	if orderid is not None:
	   self.orderid = orderid

    def _PGPEncrypt(self, credit_details):
	member_tool = getToolByName(self, 'portal_membership', None)
	if member_tool is not None:
	   member = membertool.getAuthenticatedMember()
	   member_email = member.email
	   try:
	      cout, cin = popen2('gpg --encrypt --recipient %s --armor' %s (member_email))
	   except:
	      pass

	   cin.write(str(self.PGPmailString(self, credit_details=credit_details, order_details=order_details, personal_details=personal_details)))
	   cin.close()
	   return cout.read()

    def _mailMerchant(self, REQUEST=None):
	self.doOrderemail(self)

    def _online_payment(self):
    	"""
    	This method is called by the bank
    	to update order workflow
    	"""
    	return 'toto'
    	#security.declareProtected( CMFCorePermissions.ModifyPortalContent, 'online_payment' )
    	security.declarePublic( 'online_payment' )
    	online_payment = WorkflowMethod(_online_payment,id='online_payment')


    security.declareProtected(ManageProperties, 'Description')
    def Description(self):
        """
          Return a short description
        """
        return "%s\n%s" % (string.join(map(lambda x:str(x.product), self.products),'\n') ,
        string.join((self.name,
self.organisation ,
self.address ,
self.zipcode ,
self.city,
self.country ,
self.euvat )))

    def TranslatedTitle(self):
        """
          Return a translated title
        """
        return "%s %s" % (self.gettext('Order'), self.orderid)

    def Title(self):
        """
          Return the translated title
        """
        return "Order %s" % self.orderid

    security.declareProtected(ManageProperties, 'SearchableText')
    def SearchableText(self):
        """
            text for indexing
        """
        return "%s\n%s" % (self.Title(), self.Description())

    security.declarePublic('orderLines')
    def orderLines(self):
	return int(len(self.products))

def addShopOrder(self, id, title='', REQUEST=None):
	ob=ShopOrder(id)
	self._setObject(id, ob)

Globals.InitializeClass(ShopOrder)

from Products.CMFCore.register import registerPortalContent
registerPortalContent(ShopOrder,
                      constructors=(addShopOrder,),
		      action='shoporder_edit_form',
		      icon='file_icon.gif')
